package il.ac.tau.cs.software1.wildworld;

import il.ac.tau.cs.software1.wildworld.Action;
import il.ac.tau.cs.software1.wildworld.Species;
import il.ac.tau.cs.software1.wildworld.World;

public interface Animal {

	/**
	 * Get the species this animal belongs to.
	 * @return - the species object. the return value is never null.
	 */
	public Species getSpecies();
	
	/**
	 * Set the animal's view of the world.
	 */
	public void setView(World.View view);
	
	/**
	 * Plan the animal's next action.
	 * @return - An Action object specifying the outcome of 
	 * the decision process.
	 * @see Action
	 */
	public Action act();
	
	/**
	 * get the animal's energy level
	 * @return - the animal's current energy level.
	 */
	public double getEnergy();
	
	/**
	 * Decrease the animal's energy level by a specified amount
	 * @param amount - the amount of energy to decrease. this value
	 * 				   should be positive
	 */
	public void decreaseEnergy(double amount);
	
	/**
	 * Increase the animal's energy level by a specified amount
	 * @param amount - the amount of energy to increase. this value
	 * 				   should be positive
	 */
	public void increaseEnergy(double amount);

}
