package il.ac.tau.cs.software1.wildworld;


/** 
 * Represents a specific species (e.g. CowSpecies, LionSpecies).
 * There should only be one instance of each class implementing this 
 * interface.
 */
public interface Species {
	
	/**
	 * Create a new animal that belongs to this species.
	 * There should be no other way to create an animal other than
	 * this method. 
	 * @return A new animal object. The return value is never null.
	 * @see Animal
	 */
	public Animal  newAnimal();
	
	/**
	 * Retrieve the name of the species
	 * @return The name of the species (e.g "cow" , "lion")  
	 */

	public String  getName();
	
	/**
	 * Determine whether this species is herbivore. 
	 * A species cannot be both herbivore and carnivore.
	 * @see isCarnivore
	 */
	public boolean isHerbivore();
	
	/**
	 * Determine whether this species is carnivore.
	 * A species cannot be both herbivore and carnivore.
	 * @see isHerbivore
	 */
	public boolean isCarnivore();
	
	/**
	 * Retrieve the range of sight of an animal of this species.
	 * All animals blong to this species have the same range of 
	 * sight.
	 * @return An animal's range of sight.
	 */
	public int getRangeOfVision();
	
	/**
	 * Retrieve the size of an offspring. The size of an offspring
	 * is the initial energy an animal of this species has.
	 * When an animal of this species spawns a new animal the child
	 * will have the 'SizeOfOffspring' amount of energy, while the
	 * mother's energy will decreased by the same amount.
	 * @return a value in the range 0..1
	 * @see Action.spawn
	 */
	public double getSizeOfOffspring();

}